@@ -4,13 +4,13 @@ from future.utils import PY36_PLUS
 from .os import PathLike
 
 try:
-	from pathlib import Path, PurePath
+	from pathlib import Path, PurePath  # noqa: 401
 
 	if not PY36_PLUS:
 		PurePath.__fspath__ = PurePath.__str__
 
 except ImportError:
-	from pathlib2 import Path, PurePath
+	from pathlib2 import Path, PurePath  # noqa: 401
 
 assert hasattr(PurePath, "__fspath__")
 PathLike.register(PurePath)
